==> igniteui-react-charts-16.4.1.tgz: package/ES5/HorizontalRangeCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { RangeCategorySeries } from "./RangeCategorySeries";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { NumericYAxis } from "./NumericYAxis";
import { Axis } from "./Axis";
import { Type, Point_$type, runOn, typeCast, markType } from "igniteui-react-core/ES5/type";
import { RangeValueList } from "./RangeValueList";
import { ScalerParams } from "./ScalerParams";
import { CategoryXAxis } from "./CategoryXAxis";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
var HorizontalRangeCategorySeries = /** @class */ (function (_super) {
    tslib_1.__extends(HorizontalRangeCategorySeries, _super);
    function HorizontalRangeCategorySeries() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeries.prototype.fetchXAxis = function () {
        return this.xAxis;
    };
    HorizontalRangeCategorySeries.prototype.fetchYAxis = function () {
        return this.yAxis;
    };
    HorizontalRangeCategorySeries.prototype.hm = function () {
        _super.prototype.hm.call(this);
        this.xAxis = null;
        this.yAxis = null;
    };
    HorizontalRangeCategorySeries.prototype.ah = function (a) {
        var b = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), this.lf(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[2] };
        f[1] = { $type: Point_$type, x: d[0], y: d[2] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.ai = function (a) {
        var b = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), this.lf(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[1] };
        f[1] = { $type: Point_$type, x: d[0], y: d[1] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.get_c3 = function () {
        return true;
    };
    Object.defineProperty(HorizontalRangeCategorySeries.prototype, "c3", {
        get: function () {
            return this.get_c3();
        },
        enumerable: true,
        configurable: true
    });
    HorizontalRangeCategorySeries.prototype.bd = function () {
        if (this.be == 0) {
            return 1;
        }
        else {
            return _super.prototype.bd.call(this);
        }
    };
    HorizontalRangeCategorySeries.prototype.getOffsetValue = function () {
        return this.RangeFramePreparer.r(this.xAxis, this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    };
    HorizontalRangeCategorySeries.prototype.getCategoryWidth = function () {
        return this.xAxis.getCategorySize(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    };
    HorizontalRangeCategorySeries.prototype.e8 = function (a, b) {
        return this.e9(a, b, this.xAxis, runOn(this, this.nw), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.fa = function (a, b) {
        return this.fb(a, b, this.xAxis, runOn(this, this.nw), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.d5 = function (a, b, c, d, e) {
        if (c == null) {
            return Number.POSITIVE_INFINITY;
        }
        var f = this.xAxis.jr;
        return this.d6(a, b, this.xAxis, d, e, f, runOn(this, this.nw));
    };
    HorizontalRangeCategorySeries.prototype.ej = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.ml, this.bi.bp, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.ml, this.bi.bp, d);
        return this.el(new RangeValueList(this.highColumn, this.lowColumn), a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.eh = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.ml, this.bi.bp, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.ml, this.bi.bp, d);
        return this.el(this.lowColumn, a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.ef = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.ml, this.bi.bp, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.ml, this.bi.bp, d);
        return this.el(this.highColumn, a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.k8 = function (a, b, c) {
        var _this = this;
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, runOn(this, this.ef), function (d, e) { return _this.fb(d, e, _this.xAxis, runOn(_this, _this.nw), _this.highColumn); }, function (d, e) { return _this.e9(d, e, _this.xAxis, runOn(_this, _this.nw), _this.highColumn); });
    };
    HorizontalRangeCategorySeries.prototype.la = function (a, b, c) {
        var _this = this;
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, runOn(this, this.eh), function (d, e) { return _this.fb(d, e, _this.xAxis, runOn(_this, _this.nw), _this.lowColumn); }, function (d, e) { return _this.e9(d, e, _this.xAxis, runOn(_this, _this.nw), _this.lowColumn); });
    };
    HorizontalRangeCategorySeries.prototype.lc = function (a, b, c) {
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, null, null, null);
    };
    HorizontalRangeCategorySeries.prototype.ns = function () {
        return this.yAxis != null && this.yAxis.ck();
    };
    HorizontalRangeCategorySeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case HorizontalRangeCategorySeries.$$p[0]:
                this.hs(typeCast(Axis.$, c));
                this.iw(typeCast(Axis.$, d));
                this.m6.cl.g(this.eq);
                this.i4(false);
                this.ib();
                break;
            case HorizontalRangeCategorySeries.$$p[1]:
                this.hs(typeCast(Axis.$, c));
                this.iw(typeCast(Axis.$, d));
                this.m6.cl.g(this.eq);
                this.ns();
                this.i4(false);
                this.ib();
                break;
        }
    };
    HorizontalRangeCategorySeries.prototype.o4 = function (a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.o3 = function (a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.b5) {
            return true;
        }
        return false;
    };
    Object.defineProperty(HorizontalRangeCategorySeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    HorizontalRangeCategorySeries.$t = markType(HorizontalRangeCategorySeries, 'HorizontalRangeCategorySeries', RangeCategorySeries.$);
    return HorizontalRangeCategorySeries;
}(RangeCategorySeries));
export { HorizontalRangeCategorySeries };
Type.dep(DependencyProperty, PropertyMetadata, HorizontalRangeCategorySeries, 'raisePropertyChanged', ['XAxis::o7', [CategoryAxisBase.$, null], 'YAxis::o8', [NumericYAxis.$, null]]);
/*<BeginStatics Name="Infragistics.Controls.Charts.HorizontalRangeCategorySeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.HorizontalRangeCategorySeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/HorizontalRangeCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { RangeCategorySeries } from "./RangeCategorySeries";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { NumericYAxis } from "./NumericYAxis";
import { Axis } from "./Axis";
import { Type, Point_$type, runOn, typeCast, markType } from "igniteui-react-core/ES5/type";
import { RangeValueList } from "./RangeValueList";
import { ScalerParams } from "./ScalerParams";
import { CategoryXAxis } from "./CategoryXAxis";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
var HorizontalRangeCategorySeries = /** @class */ (function (_super) {
    tslib_1.__extends(HorizontalRangeCategorySeries, _super);
    function HorizontalRangeCategorySeries() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeries.prototype.fetchXAxis = function () {
        return this.xAxis;
    };
    HorizontalRangeCategorySeries.prototype.fetchYAxis = function () {
        return this.yAxis;
    };
    HorizontalRangeCategorySeries.prototype.hm = function () {
        _super.prototype.hm.call(this);
        this.xAxis = null;
        this.yAxis = null;
    };
    HorizontalRangeCategorySeries.prototype.ah = function (a) {
        var b = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), this.lf(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[2] };
        f[1] = { $type: Point_$type, x: d[0], y: d[2] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.ai = function (a) {
        var b = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), this.lf(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[1] };
        f[1] = { $type: Point_$type, x: d[0], y: d[1] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.get_c3 = function () {
        return true;
    };
    HorizontalRangeCategorySeries.prototype.bd = function () {
        if (this.be == 0) {
            return 1;
        }
        else {
            return _super.prototype.bd.call(this);
        }
    };
    HorizontalRangeCategorySeries.prototype.getOffsetValue = function () {
        return this.RangeFramePreparer.r(this.xAxis, this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    };
    HorizontalRangeCategorySeries.prototype.getCategoryWidth = function () {
        return this.xAxis.getCategorySize(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    };
    HorizontalRangeCategorySeries.prototype.e8 = function (a, b) {
        return this.e9(a, b, this.xAxis, runOn(this, this.nw), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.fa = function (a, b) {
        return this.fb(a, b, this.xAxis, runOn(this, this.nw), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.d5 = function (a, b, c, d, e) {
        if (c == null) {
            return Number.POSITIVE_INFINITY;
        }
        var f = this.xAxis.jr;
        return this.d6(a, b, this.xAxis, d, e, f, runOn(this, this.nw));
    };
    HorizontalRangeCategorySeries.prototype.ej = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.mn, this.bi.br, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.mn, this.bi.br, d);
        return this.el(new RangeValueList(this.highColumn, this.lowColumn), a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.eh = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.mn, this.bi.br, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.mn, this.bi.br, d);
        return this.el(this.lowColumn, a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.ef = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.mn, this.bi.br, this.xAxis.b8, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.bs.mn, this.bi.br, d);
        return this.el(this.highColumn, a, this.xAxis, e, f, runOn(this, this.nw), b, c);
    };
    HorizontalRangeCategorySeries.prototype.k8 = function (a, b, c) {
        var _this = this;
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, runOn(this, this.ef), function (d, e) { return _this.fb(d, e, _this.xAxis, runOn(_this, _this.nw), _this.highColumn); }, function (d, e) { return _this.e9(d, e, _this.xAxis, runOn(_this, _this.nw), _this.highColumn); });
    };
    HorizontalRangeCategorySeries.prototype.la = function (a, b, c) {
        var _this = this;
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, runOn(this, this.eh), function (d, e) { return _this.fb(d, e, _this.xAxis, runOn(_this, _this.nw), _this.lowColumn); }, function (d, e) { return _this.e9(d, e, _this.xAxis, runOn(_this, _this.nw), _this.lowColumn); });
    };
    HorizontalRangeCategorySeries.prototype.lc = function (a, b, c) {
        return this.le(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi)), this.yAxis, this.xAxis, null, null, null);
    };
    HorizontalRangeCategorySeries.prototype.ns = function () {
        return this.yAxis != null && this.yAxis.ck();
    };
    HorizontalRangeCategorySeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case HorizontalRangeCategorySeries.$$p[0]:
                this.hs(typeCast(Axis.$, c));
                this.iw(typeCast(Axis.$, d));
                this.m6.cn.g(this.eq);
                this.i4(false);
                this.ib();
                break;
            case HorizontalRangeCategorySeries.$$p[1]:
                this.hs(typeCast(Axis.$, c));
                this.iw(typeCast(Axis.$, d));
                this.m6.cn.g(this.eq);
                this.ns();
                this.i4(false);
                this.ib();
                break;
        }
    };
    HorizontalRangeCategorySeries.prototype.o5 = function (a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.o4 = function (a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.b5) {
            return true;
        }
        return false;
    };
    Object.defineProperty(HorizontalRangeCategorySeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    HorizontalRangeCategorySeries.$t = markType(HorizontalRangeCategorySeries, 'HorizontalRangeCategorySeries', RangeCategorySeries.$);
    return HorizontalRangeCategorySeries;
}(RangeCategorySeries));
export { HorizontalRangeCategorySeries };
Type.dep(DependencyProperty, PropertyMetadata, HorizontalRangeCategorySeries, 'raisePropertyChanged', ['XAxis::o8', [CategoryAxisBase.$, null], 'YAxis::o9', [NumericYAxis.$, null]]);
